@@ -1,11 +1,16 @@
 """Test `django_fido.models`."""
 from __future__ import unicode_literals
 
+import base64
+
 from django.core.exceptions import ValidationError
 from django.test import SimpleTestCase
-from mock import sentinel
+from fido2.cose import ES256
+from fido2.ctap2 import AttestationObject, AuthenticatorData
 
-from django_fido.models import TransportsValidator, U2fDevice
+from django_fido.models import Authenticator, TransportsValidator
+
+from .data import ATTESTATION_OBJECT, CREDENTIAL_ID
 
 
 class TestTransportsValidator(SimpleTestCase):
@@ -63,50 +68,31 @@ class TestTransportsValidator(SimpleTestCase):
         self.assertRaisesMessage(ValidationError, "You're a smeghead.", validator, 'rimmer')
 
 
-class TestU2fDevice(SimpleTestCase):
-    """Test `U2fDevice` model."""
+class TestAuthenticator(SimpleTestCase):
+    """Test `Authenticator` model."""
 
-    # serialized, deserialized pairs
-    transport_values = (
-        (None, []),
-        ('usb', ['usb']),
-        ('bt,ble', ['bt', 'ble']),
-    )
+    def test_credential_id_getter(self):
+        authenticator = Authenticator(credential_id_data='Q1JFREVOVElBTF9JRA==')
 
-    def test_transports_getter(self):
-        for raw, full in self.transport_values:
-            u2f_key = U2fDevice(raw_transports=raw)
-            self.assertEqual(u2f_key.transports, full)
+        self.assertEqual(authenticator.credential_id, b'CREDENTIAL_ID')
 
-    def test_transports_setter(self):
-        for raw, full in self.transport_values:
-            u2f_key = U2fDevice()
-            u2f_key.transports = full
-            self.assertEqual(u2f_key.raw_transports, raw)
+    def test_credential_getter(self):
+        authenticator = Authenticator(attestation_data=ATTESTATION_OBJECT)
 
-    # base64 encoded, decoded pairs
-    attestation_values = (
-        (None, None),
-        ('UmltbWVyJ3Mgc2lsdmVyIHN3aW1taW5nIGNlcnRpZmljYXRl', b"Rimmer's silver swimming certificate"),
-    )
+        self.assertEqual(authenticator.credential.aaguid, b'\0' * 16)
+        self.assertEqual(authenticator.credential.credential_id, base64.b64decode(CREDENTIAL_ID))
+        self.assertIsInstance(authenticator.credential.public_key, ES256)
 
-    def test_raw_attestation_getter(self):
-        for encoded, decoded in self.attestation_values:
-            u2f_key = U2fDevice(attestation=encoded)
-            self.assertEqual(u2f_key.raw_attestation, decoded)
+    def test_attestation_getter(self):
+        authenticator = Authenticator(attestation_data=ATTESTATION_OBJECT)
 
-    def test_raw_attestation_setter(self):
-        for encoded, decoded in self.attestation_values:
-            u2f_key = U2fDevice()
-            u2f_key.raw_attestation = decoded
-            self.assertEqual(u2f_key.attestation, encoded)
+        self.assertEqual(authenticator.attestation.fmt, 'fido-u2f')
+        self.assertIsInstance(authenticator.attestation.auth_data, AuthenticatorData)
 
-    def test_get_registered_key(self):
-        u2f_key = U2fDevice(key_handle=sentinel.key_handle, app_id=sentinel.app_id, version=sentinel.version,
-                            raw_transports='usb,nfs', public_key=sentinel.public_key)
-        retgistered_key = {'keyHandle': sentinel.key_handle,
-                           'publicKey': sentinel.public_key,
-                           'appId': sentinel.app_id,
-                           'version': sentinel.version,
-                           'transports': ['usb', 'nfs']}
-        self.assertEqual(u2f_key.get_registered_key(), retgistered_key)
+    def test_attestation_setter(self):
+        authenticator = Authenticator()
+
+        authenticator.attestation = AttestationObject(base64.b64decode(ATTESTATION_OBJECT))
+
+        self.assertEqual(authenticator.attestation_data, ATTESTATION_OBJECT)
+        self.assertEqual(authenticator.credential_id_data, CREDENTIAL_ID)
